==> connector-service-1.0.0-20190709.103247-25-sources.jar: com/bizvane/connectorservice/entity/common/IntegralAdjustRequestVO.java <==
package com.bizvane.connectorservice.entity.common;

import com.bizvane.connectorservice.entity.base.BaseModel;

/**
 * @author liuying
 * @date 2018/8/9
 * @description
 */

public class IntegralAdjustRequestVO  extends BaseModel {


    /**
     * 订单编号
     */
    private String orderBillNo;

    /**
     * 线下卡号
     */
    private String offlineCardNo;

    /**
     * 调整积分数量
     */
    private Integer changeIntegral;

    /**
     * 调整类型
     */
    private Integer changeType;

    /**
     * 业务类型(统一定义)
     */
    private String businessType;

    /**
     * 调整详情
     */
    private String detail;

    public String getOrderBillNo() {
        return orderBillNo;
    }

    public void setOrderBillNo(String orderBillNo) {
        this.orderBillNo = orderBillNo;
    }

    public String getOfflineCardNo() {
        return offlineCardNo;
    }

    public void setOfflineCardNo(String offlineCardNo) {
        this.offlineCardNo = offlineCardNo;
    }

    public Integer getChangeIntegral() {
        return changeIntegral;
    }

    public void setChangeIntegral(Integer changeIntegral) {
        this.changeIntegral = changeIntegral;
    }

    public Integer getChangeType() {
        return changeType;
    }

    public void setChangeType(Integer changeType) {
        this.changeType = changeType;
    }

    public String getBusinessType() {
        return businessType;
    }

    public void setBusinessType(String businessType) {
        this.businessType = businessType;
    }

    public String getDetail() {
        return detail;
    }

    public void setDetail(String detail) {
        this.detail = detail;
    }
}

==> connector-service-1.0.0-20190813.072142-40-sources.jar: com/bizvane/connectorservice/entity/common/IntegralAdjustRequestVO.java <==
package com.bizvane.connectorservice.entity.common;

import com.bizvane.connectorservice.entity.base.BaseModel;

/**
 * @author liuying
 * @date 2018/8/9
 * @description
 */

public class IntegralAdjustRequestVO  extends BaseModel {


    /**
     * 订单编号
     */
    private String orderBillNo;

    /**
     * 线下卡号
     */
    private String offlineCardNo;

    /**
     * 调整积分数量
     */
    private Integer changeIntegral;

    /**
     * 调整类型
     */
    private Integer changeType;

    /**
     * 业务类型(统一定义)
     */
    private String businessType;

    /**
     * 调整详情
     */
    private String detail;

    /**
     * 所属门店UR
     */
    private String  storeId;
    /**
     * 积分数额UR
     */
    private Double pointsAmount;

    /**
     * 来源 UR
     */
    private String  source;

    public String getOrderBillNo() {
        return orderBillNo;
    }

    public void setOrderBillNo(String orderBillNo) {
        this.orderBillNo = orderBillNo;
    }

    public String getOfflineCardNo() {
        return offlineCardNo;
    }

    public void setOfflineCardNo(String offlineCardNo) {
        this.offlineCardNo = offlineCardNo;
    }

    public Integer getChangeIntegral() {
        return changeIntegral;
    }

    public void setChangeIntegral(Integer changeIntegral) {
        this.changeIntegral = changeIntegral;
    }

    public Integer getChangeType() {
        return changeType;
    }

    public void setChangeType(Integer changeType) {
        this.changeType = changeType;
    }

    public String getBusinessType() {
        return businessType;
    }

    public void setBusinessType(String businessType) {
        this.businessType = businessType;
    }

    public String getDetail() {
        return detail;
    }

    public void setDetail(String detail) {
        this.detail = detail;
    }

    public String getStoreId() {
        return storeId;
    }

    public void setStoreId(String storeId) {
        this.storeId = storeId;
    }

    public Double getPointsAmount() {
        return pointsAmount;
    }

    public void setPointsAmount(Double pointsAmount) {
        this.pointsAmount = pointsAmount;
    }

    public String getSource() {
        return source;
    }

    public void setSource(String source) {
        this.source = source;
    }
}
